@@ -1,5 +1,4 @@
 from abc import ABC, abstractmethod
-from dataclasses import dataclass
 from rx.core.typing import Observable
 
 from typing import (
@@ -160,37 +159,30 @@ class DeviceSetEvent(TypedDict):
     pass
 
 
-@dataclass
 class LightState(BaseState, LightSetEvent):
     pass
 
 
-@dataclass
 class MotionState(BaseState, MotionSetEvent):
     pass
 
 
-@dataclass
 class AudioState(BaseState, AudioSetEvent):
     pass
 
 
-@dataclass
 class DoorbellState(BaseState, DoorbellSetEvent):
     pass
 
 
-@dataclass
 class SirenState(BaseState, SirenSetEvent):
     pass
 
 
-@dataclass
 class ObjectState(BaseState, ObjectSetEvent):
     pass
 
 
-@dataclass
 class BatteryState(BaseState, BatterySetEvent):
     pass
 
@@ -642,6 +634,7 @@ class CameraDevice(Protocol):
     has_audio_detector: bool
     has_object_detector: bool
     has_ptz: bool
+
     on_started: Observable
     on_light_switched: Observable
     on_motion_detected: Observable
@@ -650,6 +643,7 @@ class CameraDevice(Protocol):
     on_doorbell_pressed: Observable
     on_siren_detected: Observable
     on_battery_changed: Observable
+
     stream_source: CameraSource
     snapshot_source: CameraSource
     recording_source: CameraSource
@@ -704,7 +698,13 @@ CameraUpdatedCallback = Callable[[str, CameraDevice], None]
 
 
 @runtime_checkable
-class DeviceManager(Protocol):  # todo: add methods
+class DeviceManager(Protocol):
+    async def get_camera_by_id(self, id: str) -> Optional[CameraDevice]: ...
+    async def get_camera_by_name(self, name: str) -> Optional[CameraDevice]: ...
+    async def create_camera(self, config: CameraConfig) -> CameraDevice: ...
+    async def remove_camera_by_id(self, id: str) -> None: ...
+    async def remove_camera_by_name(self, name: str) -> None: ...
+
     @overload
     def on(
         self, event: Literal["cameraSelected"], listener: CameraSelectedCallback
@@ -804,7 +804,5 @@ class BasePlugin(ABC):
         pass
 
     @abstractmethod
-    def configure_cameras(
-        self, cameras: List[Any]
-    ) -> None:  # todo: replace with Camera Device
+    def configure_cameras(self, cameras: List[CameraDevice]) -> None:
         pass
